@@ -6,7 +6,7 @@
 
 #Author: Christos Zamantzas <christos.zamantzas@gmail.com>
 #Contributions: Frank Visser - import, decrypt and encrypt from config file the user variables.
-Version = '0.6-3'
+Version = '0.7-3'
 
 import os
 import sys
@@ -15,9 +15,9 @@ import string
 import base64
 
 from Crypto.Cipher import AES
-from PyQt4 import QtGui,QtCore
-from PyQt4.QtCore import SIGNAL, Qt
 from PyQt4.QtGui import *
+from PyQt4.QtCore import *
+from PyQt4.QtMaemo5 import *
 
 from smsconEditorMainGUI import *
 from smsconEditorAskPass import *
@@ -34,7 +34,7 @@ PassFile      = 'smsconEditorPass'             # name of password file
 ##############################################################
 
 def showMessage(message):
-    """ Method to display a message to the user that waits for a confirmation. """
+    ''' Method to display a message to the user that waits for a confirmation. '''
 
     os.system('dbus-send --type=method_call --dest=org.freedesktop.Notifications \
                /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteDialog \
@@ -43,7 +43,7 @@ def showMessage(message):
 ##############################################################  
 
 def showQuickMessage(message):
-    """ Method to display a message to the user. """
+    ''' Method to display a message to the user. '''
 
     os.system('dbus-send --type=method_call --dest=org.freedesktop.Notifications \
                /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint \
@@ -52,7 +52,7 @@ def showQuickMessage(message):
 ##############################################################
 
 def CheckFile(Path, File):
-    """ Check if a file exists. """
+    ''' Check if a file exists. '''
 
     try:
         f = open(Path + File, 'r')
@@ -65,7 +65,7 @@ def CheckFile(Path, File):
 ##############################################################  
 
 def doCheckPassword(password):  ### FIXME: what should be the behaviour if password is missing?
-    """ Check the given password. """
+    ''' Check the given password. '''
     
     if CheckFile(AppPath, PassFile) == True:
        f = open(AppPath + PassFile, 'r')
@@ -90,9 +90,11 @@ def doCheckPassword(password):  ### FIXME: what should be the behaviour if passw
 ##############################################################  
 
 def doCopyConfig():
+    '''Make a copy of the configuration for safe editing.'''  
+
     #Check if configuration file exists.
     if CheckFile(MainPath, ConfigFile) == True:
-       #Make a copy of the configuration for safe editing.  
+       #Make the copy
        os.system('cp %s %s' % (MainPath + ConfigFile, Path))
     else:
        message = 'Reading SMSCON settings gave a FATAL ERROR.\nThe configuration file does not exist or it is corrupted.'
@@ -111,7 +113,7 @@ def doCopyConfig():
 ##############################################################  
 
 def doUpdateConfig():
-    """ Copy the config file with the edited and restart deamon. """
+    ''' Replace the config file with the edited and restart deamon. '''
     Delay = 0.5
 
     time.sleep(Delay)
@@ -123,7 +125,7 @@ def doUpdateConfig():
 
 ##############################################################  
 ##   
-## Load user settings from smscon_config file
+## Load the user settings from smscon_config file
 ## Contribution by Frank Visser
 ##
 
@@ -143,6 +145,7 @@ ConfigVars = ['SENDERNUMBER',
                'COM_TRACKON',
                'COM_TRACKOFF',
                'COM_CUSTOM',
+               'COM_SHELL',
                'USER',         
                'PASSWORD',        
                'EMAILFROM',       
@@ -152,8 +155,12 @@ ConfigVars = ['SENDERNUMBER',
                'REMOTEPORT',           
                'REMOTEUSER',       
                'REMOTEPASSWORD',
+               'DISABLESMS',
                'COMMANDREPLY',
                'AUTODEVICELOCK',
+               'AUTOBATREPORT',
+               'SIMUNLOCK',
+               'SILENCEDEVICE',
                'KEYBOARDDETECT',
                'GPSTIMEOUT',
                'GPSPOLLING',
@@ -250,7 +257,9 @@ class MyStartupDialog(QtGui.QDialog): ### FIXME: add 3 re-tries for wrong passwo
           QtGui.QDialog.__init__(self, parent)
           self.ui = Ui_DialogStart()
           self.ui.setupUi(self)
-          
+          ##self.setAttribute(Qt.WA_Maemo5AutoOrientation, True)
+          self.setAttribute(Qt.WA_Maemo5StackedWindow, True)
+
           ##Connect the button
           QtCore.QObject.connect(self.ui.btnEnterPassword, QtCore.SIGNAL('clicked()'), self.doEnterPassword)
                
@@ -288,30 +297,30 @@ class MyMainWindow(QtGui.QMainWindow):
           #Open Start Dialog - request password
           mydialog = MyStartupDialog()
           mydialog.exec_()
-        
+
           ##Build parent user interface
           QtGui.QWidget.__init__(self, parent)
           self.ui = Ui_SMSCON_GUI_elements()
           self.ui.setupUi(self)
+          ##self.setAttribute(Qt.WA_Maemo5AutoOrientation, True)
+          self.setAttribute(Qt.WA_Maemo5StackedWindow, True)
 
           ##Connect the GUI Buttons with actions
             ##Create Settings
           QtCore.QObject.connect(self.ui.btnCreateConfigGeneral, QtCore.SIGNAL('clicked()'), self.doCreateConfigGeneral)
           QtCore.QObject.connect(self.ui.btnCreateConfigEmail, QtCore.SIGNAL('clicked()'), self.doCreateConfigEmail)
           QtCore.QObject.connect(self.ui.btnCreateConfigSSH, QtCore.SIGNAL('clicked()'), self.doCreateConfigSSH)
-          QtCore.QObject.connect(self.ui.btnCreateConfigCommands1, QtCore.SIGNAL('clicked()'), self.doCreateConfigCommands1)
-          QtCore.QObject.connect(self.ui.btnCreateConfigCommands2, QtCore.SIGNAL('clicked()'), self.doCreateConfigCommands2)
+          QtCore.QObject.connect(self.ui.btnCreateConfigCommands, QtCore.SIGNAL('clicked()'), self.doCreateConfigCommands)
             ##Initialise
           QtCore.QObject.connect(self.ui.btnInit, QtCore.SIGNAL('clicked()'), self.doInit)
           QtCore.QObject.connect(self.ui.btnReset, QtCore.SIGNAL('clicked()'), self.doReset)
           QtCore.QObject.connect(self.ui.btnDelIMSI, QtCore.SIGNAL('clicked()'), self.doDelIMSI)
-          QtCore.QObject.connect(self.ui.btnDelConfig, QtCore.SIGNAL('clicked()'), self.doDelConfig)
+          QtCore.QObject.connect(self.ui.btnAddIMSI, QtCore.SIGNAL('clicked()'), self.doAddIMSI)
           QtCore.QObject.connect(self.ui.btnStart, QtCore.SIGNAL('clicked()'), self.doStart)
           QtCore.QObject.connect(self.ui.btnStop, QtCore.SIGNAL('clicked()'), self.doStop)
           QtCore.QObject.connect(self.ui.btnBoot, QtCore.SIGNAL('clicked()'), self.doBoot)
           QtCore.QObject.connect(self.ui.btnUnBoot, QtCore.SIGNAL('clicked()'), self.doUnBoot)
-          QtCore.QObject.connect(self.ui.btnPrefix1, QtCore.SIGNAL('clicked()'), self.doPrefix1)
-          QtCore.QObject.connect(self.ui.btnPrefix2, QtCore.SIGNAL('clicked()'), self.doPrefix2)
+          QtCore.QObject.connect(self.ui.btnPrefix, QtCore.SIGNAL('clicked()'), self.doPrefix)
             ##Test buttons
           QtCore.QObject.connect(self.ui.btnTestMail1, QtCore.SIGNAL('clicked()'), self.doSendTestMail1)
           QtCore.QObject.connect(self.ui.btnTestMail2, QtCore.SIGNAL('clicked()'), self.doSendTestMail2)
@@ -330,7 +339,7 @@ class MyMainWindow(QtGui.QMainWindow):
           self.SetValues()
                
        def SetValues(self):
-          """ Set Values """
+          ''' Set values read in the GUI'''
           
           self.ui.linePhone.setText("%s" % SENDERNUMBER)
           self.ui.lineGPSTimeout.setText("%s" % GPSTIMEOUT)  
@@ -377,7 +386,27 @@ class MyMainWindow(QtGui.QMainWindow):
              self.ui.checkBoxDeviceLock.setChecked(True)
           else:
              self.ui.checkBoxDeviceLock.setChecked(False)
-          
+
+          if AUTOBATREPORT  == 'yes':
+             self.ui.checkBoxLowBattery.setChecked(True)
+          else:
+             self.ui.checkBoxLowBattery.setChecked(False)
+             
+          if DISABLESMS     == 'yes':
+             self.ui.checkBoxNoSMS.setChecked(True)
+          else:
+             self.ui.checkBoxNoSMS.setChecked(False)
+             
+          if SIMUNLOCK  == 'yes':
+             self.ui.checkBoxNewSIMUnlock.setChecked(True)
+          else:
+             self.ui.checkBoxNewSIMUnlock.setChecked(False)
+             
+          if SILENCEDEVICE  == 'yes':
+             self.ui.checkBoxSilence.setChecked(True)
+          else:
+             self.ui.checkBoxSilence.setChecked(False)
+             
           if KEYBOARDDETECT == 'yes':
              self.ui.checkBoxKeyboardDetect.setChecked(True)
           else:
@@ -397,13 +426,10 @@ class MyMainWindow(QtGui.QMainWindow):
           self.ui.lineTrackOn.setText(  "%s" % COM_TRACKON)
           self.ui.lineTrackOff.setText( "%s" % COM_TRACKOFF)
           self.ui.lineScript.setText(   "%s" % COM_CUSTOM)
+          self.ui.lineShell.setText(    "%s" % COM_SHELL)
        
        def doAbout(self):
-          msg = "The SMSCON Editor is a user interface to the configuration of the SMSCON.\n"
-          msg += "It provides the ability to edit the options and name the secret pass-phrases of the commands used for controlling the device.\n"
-          msg += "In addition, it provides an interface to initialise and configure the SMSCON daemon.\n"
-          msg += "For more info see: http://wiki.maemo.org/SMSCON_Editor"
-          QMessageBox.about(self, ("About - SMSCON Editor ver. %s " % Version ) , msg)
+          self.aboutWin = SMSCONAbout(self)
 
        def doCredits(self):
           msg = unichr(int('00A9', 16)) + "SMSCON - 2010, Frank Visser (digitalvoid)\n"
@@ -416,29 +442,25 @@ class MyMainWindow(QtGui.QMainWindow):
        ##TAB: INIT
        def doInit(self):
           os.system('sudo smscon -init')
-          message = 'SMSCON has been initialised to the default configuration.  \
+          message = 'SMSCON has been initialised to the default configuration. \
                     \nThis editor will now quit...\n\nYou will need to open it again and edit your new configuration.'
           showMessage(message)
           sys.exit(1)
             
        def doReset(self):
           os.system('sudo smscon -reset')
-          message = 'SMSCON has been reset, i.e. the process has been stopped, the config file has been deleted\
+          message = 'SMSCON has been reset, i.e. the daemon has been stopped, the config file has been deleted\
                      and the deamon has been removed from the boot sequence.\
                      \n\nNext you will need to initialise it and edit your new configuration.'
           showMessage(message)
           #sys.exit(1)
 
        def doDelIMSI(self):
-          os.system('sudo smscon -del imsi')
-          message = 'The IMSI code has been deleted.\
-                     \n\nYou can change the SIM card now.'
+          message = os.popen('sudo smscon -del imsi').read()
           showMessage(message)
 
-       def doDelConfig(self):
-          os.system('sudo smscon -del config')
-          message = 'The Configuration file has been deleted.\
-                     \n\nYou need to initialise before any other action.'
+       def doAddIMSI(self):
+          message = os.popen('sudo smscon -add imsi').read()
           showMessage(message)
 
        def doStart(self):
@@ -470,13 +492,37 @@ class MyMainWindow(QtGui.QMainWindow):
              CommandReply = "yes"
           else:
              CommandReply = "no"
-         
+             
           AutoDeviceLock = self.ui.checkBoxDeviceLock.isChecked()
           if AutoDeviceLock is True:
              AutoDeviceLock = "yes"
           else:
              AutoDeviceLock = "no"
+             
+          LowBattery = self.ui.checkBoxLowBattery.isChecked()
+          if LowBattery is True:
+             LowBattery = "yes"
+          else:
+             LowBattery = "no"
+             
+          NoSMS = self.ui.checkBoxNoSMS.isChecked()
+          if NoSMS is True:
+             NoSMS = "yes"
+          else:
+             NoSMS = "no"
 
+          NewSIMUnlock = self.ui.checkBoxNewSIMUnlock.isChecked()
+          if NewSIMUnlock is True:
+             NewSIMUnlock = "yes"
+          else:
+             NewSIMUnlock = "no"
+             
+          Silence = self.ui.checkBoxSilence.isChecked()
+          if Silence is True:
+             Silence = "yes"
+          else:
+             Silence = "no"
+             
           KeyboardDetect = self.ui.checkBoxKeyboardDetect.isChecked()
           if KeyboardDetect is True:
              KeyboardDetect = "yes"
@@ -500,6 +546,14 @@ class MyMainWindow(QtGui.QMainWindow):
                 destination.write('GPSSEND           = \'%s\'\n' % GPSSend)
              elif Line.startswith("AUTODEVICELOCK"):
                 destination.write('AUTODEVICELOCK    = \'%s\'\n' % AutoDeviceLock)
+             elif Line.startswith("AUTOBATREPORT"):
+                destination.write('AUTOBATREPORT     = \'%s\'\n' % LowBattery)
+             elif Line.startswith("DISABLESMS"):
+                destination.write('DISABLESMS        = \'%s\'\n' % NoSMS)
+             elif Line.startswith("SIMUNLOCK"):
+                destination.write('SIMUNLOCK         = \'%s\'\n' % NewSIMUnlock)
+             elif Line.startswith("SILENCEDEVICE"):
+                destination.write('SILENCEDEVICE     = \'%s\'\n' % Silence)
              elif Line.startswith("COMMANDREPLY"):
                 destination.write('COMMANDREPLY      = \'%s\'\n' % CommandReply)
              elif Line.startswith("KEYBOARDDETECT"):
@@ -555,7 +609,6 @@ class MyMainWindow(QtGui.QMainWindow):
           showQuickMessage(message)
           doUpdateConfig()
 
-
           message = 'The settings have been successfully saved.\
                     \nUser name: %s\nPassword: %s\nEmail address: %s\nMail server: %s - Port: %s' % (EmailUsername,
                                                                                                      EmailPassword,
@@ -573,41 +626,25 @@ class MyMainWindow(QtGui.QMainWindow):
           showMessage(message)
             
        ##TAB: Commands Renaming       
-       def doPrefix1(self):
-          prefix = self.ui.linePrefix1.text()
+       def doPrefix(self):
+          prefix = self.ui.linePrefix.text()
           self.ui.lineCheck.setText(    "%s" % prefix + COM_CHECK)
-          #self.ui.lineReboot.setText(   "%s" % prefix + COM_REBOOT)
-          #self.ui.linePowerOff.setText( "%s" % prefix + COM_POWEROFF)
-          #self.ui.linePower.setText(    "%s" % prefix + COM_POWER)
+          self.ui.lineReboot.setText(   "%s" % prefix + COM_REBOOT)
+          self.ui.linePowerOff.setText( "%s" % prefix + COM_POWEROFF)
+          self.ui.linePower.setText(    "%s" % prefix + COM_POWER)
           self.ui.lineLocation.setText( "%s" % prefix + COM_LOCATION)
-          #self.ui.lineRemoteOn.setText( "%s" % prefix + COM_REMOTEON)
-          #self.ui.lineRemoteOff.setText("%s" % prefix + COM_REMOTEOFF)
+          self.ui.lineRemoteOn.setText( "%s" % prefix + COM_REMOTEON)
+          self.ui.lineRemoteOff.setText("%s" % prefix + COM_REMOTEOFF)
           self.ui.lineCamera.setText(   "%s" % prefix + COM_CAMERA)
           self.ui.lineCall.setText(     "%s" % prefix + COM_CALL)
           self.ui.lineLock.setText(     "%s" % prefix + COM_LOCK)
           self.ui.lineUnlock.setText(   "%s" % prefix + COM_UNLOCK)
           self.ui.lineTrackOn.setText(  "%s" % prefix + COM_TRACKON)
           self.ui.lineTrackOff.setText( "%s" % prefix + COM_TRACKOFF)
-          #self.ui.lineScript.setText(   "%s" % prefix + COM_CUSTOM)
-
-       def doPrefix2(self):
-          prefix = self.ui.linePrefix2.text()
-          #self.ui.lineCheck.setText(    "%s" % prefix + COM_CHECK)
-          self.ui.lineReboot.setText(   "%s" % prefix + COM_REBOOT)
-          self.ui.linePowerOff.setText( "%s" % prefix + COM_POWEROFF)
-          self.ui.linePower.setText(    "%s" % prefix + COM_POWER)
-          #self.ui.lineLocation.setText( "%s" % prefix + COM_LOCATION)
-          self.ui.lineRemoteOn.setText( "%s" % prefix + COM_REMOTEON)
-          self.ui.lineRemoteOff.setText("%s" % prefix + COM_REMOTEOFF)
-          #self.ui.lineCamera.setText(   "%s" % prefix + COM_CAMERA)
-          #self.ui.lineCall.setText(     "%s" % prefix + COM_CALL)
-          #self.ui.lineLock.setText(     "%s" % prefix + COM_LOCK)
-          #self.ui.lineUnlock.setText(   "%s" % prefix + COM_UNLOCK)
-          #self.ui.lineTrackOn.setText(  "%s" % prefix + COM_TRACKON)
-          #self.ui.lineTrackOff.setText( "%s" % prefix + COM_TRACKOFF)
           self.ui.lineScript.setText(   "%s" % prefix + COM_CUSTOM)
-             
-       def doCreateConfigCommands1(self):
+          self.ui.lineShell.setText(    "%s" % prefix + COM_SHELL)
+          
+       def doCreateConfigCommands(self):
 
           Check    = self.ui.lineCheck.text()
           Location = self.ui.lineLocation.text()
@@ -617,7 +654,14 @@ class MyMainWindow(QtGui.QMainWindow):
           Call     = self.ui.lineCall.text()
           Lock     = self.ui.lineLock.text()
           Unlock   = self.ui.lineUnlock.text()
-
+          RemoteOn  = self.ui.lineRemoteOn.text()
+          RemoteOff = self.ui.lineRemoteOff.text()
+          Power     = self.ui.linePower.text()
+          Reboot    = self.ui.lineReboot.text()
+          PowerOff  = self.ui.linePowerOff.text()
+          Script    = self.ui.lineScript.text()
+          Shell     = self.ui.lineShell.text()
+          
           #Update of the config file.
           os.rename( Path + ConfigFile, Path + ConfigFile + "~" )
           destination = open( Path + ConfigFile, "w" )
@@ -639,33 +683,7 @@ class MyMainWindow(QtGui.QMainWindow):
                 destination.write('COM_LOCK          = \'%s\'\n' % Lock)
              elif Line.startswith("COM_UNLOCK"):
                 destination.write('COM_UNLOCK        = \'%s\'\n' % Unlock)
-             else: 
-                destination.write( Line )
-          source.close()
-          destination.close()
-
-          message = 'Updating. Please wait..'
-          showQuickMessage(message)
-          doUpdateConfig()
-
-          message = 'Successfully Updated the Command Names..'
-          showMessage(message)
-
-       def doCreateConfigCommands2(self):
-
-          RemoteOn  = self.ui.lineRemoteOn.text()
-          RemoteOff = self.ui.lineRemoteOff.text()
-          Power     = self.ui.linePower.text()
-          Reboot    = self.ui.lineReboot.text()
-          PowerOff  = self.ui.linePowerOff.text()
-          Script    = self.ui.lineScript.text()
-          
-          #Update of the config file.
-          os.rename( Path + ConfigFile, Path + ConfigFile + "~" )
-          destination = open( Path + ConfigFile, "w" )
-          source = open( Path + ConfigFile + "~", "r" )
-          for Line in source:
-             if   Line.startswith("COM_REMOTEON"):
+             elif Line.startswith("COM_REMOTEON"):
                 destination.write('COM_REMOTEON      = \'%s\'\n' % RemoteOn)
              elif Line.startswith("COM_REMOTEOFF"):
                 destination.write('COM_REMOTEOFF     = \'%s\'\n' % RemoteOff)
@@ -677,6 +695,8 @@ class MyMainWindow(QtGui.QMainWindow):
                 destination.write('COM_POWEROFF      = \'%s\'\n' % PowerOff)
              elif Line.startswith("COM_CUSTOM"):
                 destination.write('COM_CUSTOM        = \'%s\'\n' % Script)
+             elif Line.startswith("COM_SHELL"):
+                destination.write('COM_SHELL         = \'%s\'\n' % Shell)                   
              else: 
                 destination.write( Line )
           source.close()
@@ -772,20 +792,31 @@ class MyPasswordDialog(QtGui.QDialog):
           QtGui.QDialog.__init__(self, parent)
           self.ui = Ui_DialogPassword()
           self.ui.setupUi(self)
+          ##self.setAttribute(Qt.WA_Maemo5AutoOrientation, True)
+          self.setAttribute(Qt.WA_Maemo5StackedWindow, True)
           
           ##Connect the button
           QtCore.QObject.connect(self.ui.btnNewPassword, QtCore.SIGNAL('clicked()'), self.doNewPassword)
              
        def doNewPassword(self):
+
+          NewPassword1 = self.ui.lineNewPassword1.text()
+          NewPassword2 = self.ui.lineNewPassword2.text()
+          
+          if   NewPassword1 != NewPassword2:
+             message = 'The two cases are not equal. No change has been made.'
+             showMessage(message)
+             self.close()
+          elif NewPassword1 == NewPassword2:
+             NewPassword = NewPassword1
+             if NewPassword == '':
+               NewPassword = '12345'
           try:
-            os.remove( AppPath + PassFile )
-          except:
-            pass 
-          time.sleep(1)
-          NewPassword = self.ui.lineNewPassword.text()
-          if NewPassword == '':
-             NewPassword = '12345'
-          try:
+             try:
+               os.remove( AppPath + PassFile )
+             except:
+               pass 
+             time.sleep(1)             
              os.system('sudo %ssmsconEditorCreatePass %s %s' % (AppPath, NewPassword, AppPath + PassFile))
           except:
              message = 'The new password hash could not be stored.'
@@ -798,8 +829,93 @@ class MyPasswordDialog(QtGui.QDialog):
        
 ##############################################################
 
+class SMSCONAbout(QtGui.QMainWindow):
+    '''About Window'''
+    def __init__(self, parent=None):
+        QMainWindow.__init__(self,parent)
+        self.parent = parent
+        self.setAttribute(Qt.WA_Maemo5AutoOrientation, True)
+        self.setAttribute(Qt.WA_Maemo5StackedWindow, True)
+        self.setWindowTitle("SMSCON Editor About")
+
+        aboutScrollArea = QScrollArea(self)
+        aboutScrollArea.setWidgetResizable(True)
+        awidget = QWidget(aboutScrollArea)
+        awidget.setMinimumSize(470,1100)
+        awidget.setSizePolicy( QSizePolicy.Expanding, QSizePolicy.Expanding )
+        aboutScrollArea.setSizePolicy( QSizePolicy.Expanding, QSizePolicy.Expanding )
+        #Kinetic scroller is available on Maemo and should be on meego
+        try:
+            scroller = aboutScrollArea.property("kineticScroller").toPyObject()
+            scroller.setEnabled(True)
+        except:
+            pass
+
+        aboutLayout = QVBoxLayout(awidget)
+
+        aboutIcon = QLabel()
+        aboutIcon.setPixmap( QIcon.fromTheme('smscon-editor').pixmap(48,48) )
+        aboutIcon.setAlignment( Qt.AlignCenter or Qt.AlignHCenter )
+        aboutIcon.resize(128,128)
+        aboutLayout.addWidget(aboutIcon)
+
+        aboutLabel = QLabel('''<center><b>SMSCON Editor</b> 
+                                   <br>version: %s
+                                   <br>
+                                   <br>
+                                   <b>The SMSCON Editor is a user interface 
+                                   <br>to the configuration of the SMSCON.</b>
+                                   <br>
+                                   <br>Licenced under GPLv2
+                                   <br>by <b>Christos Zamantzas</b> (Saturn)
+                                   <br>
+                                   <br>It provides the ability to edit 
+                                   <br>the options and name the secret  
+                                   <br>pass-phrases of the commands used 
+                                   <br>for controlling the device.
+                                   <br>
+                                   <br>In addition, it provides an interface 
+                                   <br>to initialise and configure the 
+                                   <br>SMSCON daemon.
+                                   <br>
+                                   <br>Additional information on the usage, 
+                                   <br>settings and implications can be found in
+                                   <br>the wiki pages (see buttons at the end).
+                                   <br>
+                                   <br>
+                                   <br><b>Thanks to:</b>
+                                   <br><b>Frank Visser</b> (Digitalvoid) for 
+                                   <br>the code to import, decrypt and encrypt 
+                                   <br>the user variables at the config file.
+                                   <br>
+                                   <br><b>Benoit HERVIER</b> at http://khertan.net/
+                                   <br>for the code used in this about window.
+                                   <br>
+                                   </center>''' % Version)
+        aboutLayout.addWidget(aboutLabel)
+        self.wiki1_button = QPushButton('SMSCON')
+        self.wiki1_button.clicked.connect(self.open_wiki1)
+        self.wiki2_button = QPushButton('SMSCON Editor')
+        self.wiki2_button.clicked.connect(self.open_wiki2)
+        awidget2 = QWidget()
+        buttonLayout = QHBoxLayout(awidget2)        
+        buttonLayout.addWidget(self.wiki1_button)
+        buttonLayout.addWidget(self.wiki2_button)
+        aboutLayout.addWidget(awidget2)
+        
+        awidget.setLayout(aboutLayout)
+        aboutScrollArea.setWidget(awidget)
+        self.setCentralWidget(aboutScrollArea)
+        self.show()        
+        
+    def open_wiki1(self):
+        QDesktopServices.openUrl(QUrl('http://wiki.maemo.org/SMSCON'))
+    def open_wiki2(self):
+        QDesktopServices.openUrl(QUrl('http://wiki.maemo.org/SMSCON_Editor'))
+
+
+##############################################################        
              
-#if __name__ == "__main__":
 class smsconEditorMain():
         
           ##############################################################  
